@@ -1,23 +1,55 @@
+# Copyright (c) 2010-2013 by Yaco Sistemas <ant30tx@gmail.com> or <goinnn@gmail.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this programe.  If not, see <http://www.gnu.org/licenses/>.
+
 import copy
+import sys
 
 from django import template
 from django.conf import settings
+from django.core.urlresolvers import reverse
 from django.template.loader import render_to_string
 from django.template import TemplateSyntaxError, TokenParser, Node, Variable
 try:
     from django.template.base import _render_value_in_context
-except ImportError: # Django 1.1 fallback
+except ImportError:   # Django 1.1 fallback
     from django.template import _render_value_in_context
 
 from django.utils.translation import get_language
 from django.utils.translation.trans_real import catalog
 
+from ..settings import get_user_can_translate
+
+
+if sys.version_info.major == 2:
+    string = basestring
+else:
+    string = str
+
 
 register = template.Library()
 
 
-def get_media_url():
-    return getattr(settings, 'INLINETRANS_MEDIA_URL', settings.MEDIA_URL + 'inlinetrans/')
+def get_static_url(subfix='inlinetrans'):
+    static_prefix = getattr(settings, 'INLINETRANS_STATIC_URL', None)
+    if static_prefix:
+        return static_prefix
+    static_prefix = getattr(settings, 'INLINETRANS_MEDIA_URL', None)
+    if static_prefix:
+        return static_prefix
+    static_url = getattr(settings, 'STATIC_URL', getattr(settings, 'MEDIA_URL'))
+    return '%s%s/' % (static_url, subfix)
 
 
 def get_language_name(lang):
@@ -42,7 +74,7 @@ class InlineTranslateNode(Node):
     def __init__(self, filter_expression, noop):
         self.noop = noop
         self.filter_expression = filter_expression
-        if isinstance(self.filter_expression.var, basestring):
+        if isinstance(self.filter_expression.var, string):
             self.filter_expression.var = Variable(u"'%s'" % self.filter_expression.var)
 
     def render(self, context):
@@ -52,7 +84,7 @@ class InlineTranslateNode(Node):
             user = getattr(context.get('request'), 'user', None)
         else:
             user = None
-        if not (user and user.is_staff):
+        if not (user and get_user_can_translate(user)):
             self.filter_expression.var.translate = not self.noop
             output = self.filter_expression.resolve(context)
             return _render_value_in_context(output, context)
@@ -65,8 +97,11 @@ class InlineTranslateNode(Node):
         cat.add_fallback(NotTranslated)
         styles = ['translatable']
         try:
-            msgstr = cat.ugettext(msgid)
-        except ValueError:
+            if sys.version_info.major == 2:
+                msgstr = cat.ugettext(msgid)
+            else:
+                msgstr = cat.gettext(msgid)
+        except (ValueError, AttributeError):
             styles.append("untranslated")
             msgstr = msgid
         return render_to_string('inlinetrans/inline_trans.html',
@@ -98,36 +133,52 @@ register.tag('itrans', inline_trans)
 
 
 @register.inclusion_tag('inlinetrans/inline_header.html', takes_context=True)
-def inlinetrans_media(context):
+def inlinetrans_static(context):
     tag_context = {
-        'is_staff': False,
-        'INLINETRANS_MEDIA_URL': get_media_url(),
+        'can_translate': False,
+        'is_staff': False,  # backward compatible
+        'INLINETRANS_STATIC_URL': get_static_url(),
+        'INLINETRANS_MEDIA_URL': get_static_url(),  # backward compatible
         'request': context['request'],
     }
-    if 'user' in context and context['user'].is_staff:
+    user = context.get('user', None)
+    if user and get_user_can_translate(user):
         tag_context.update({
-            'is_staff': True,
+            'can_translate': True,
+            'is_staff': True,  # backward compatible
             'language': get_language_name(get_language()),
         })
     return tag_context
 
 
+@register.inclusion_tag('inlinetrans/inline_header.html', takes_context=True)
+def inlinetrans_media(context):  # backward compatible
+    return inlinetrans_static(context)
+
+
 @register.inclusion_tag('inlinetrans/inline_toolbar.html', takes_context=True)
 def inlinetrans_toolbar(context, node_id):
     tag_context = {
-        'INLINETRANS_MEDIA_URL': get_media_url(),
+        'INLINETRANS_STATIC_URL': get_static_url(),
+        'INLINETRANS_MEDIA_URL': get_static_url(),  # backward compatible
         'request': context['request'],
+        'set_new_translation_url': reverse('inlinetrans.views.set_new_translation'),
+        'do_restart_url': reverse('inlinetrans.views.do_restart'),
     }
-    if 'user' in context and context['user'].is_staff:
+    user = context.get('user', None)
+    if user and get_user_can_translate(user):
         tag_context.update({
-            'is_staff': True,
+            'can_translate': True,
+            'is_staff': True,  # backward compatible
             'language': get_language_name(get_language()),
             'node_id': node_id,
         })
     else:
         tag_context.update({
-            'is_staff': False,
-            'INLINETRANS_MEDIA_URL': get_media_url(),
+            'can_translate': False,
+            'is_staff': False,  # backward compatible
+            'INLINETRANS_STATIC_URL': get_static_url(),
+            'INLINETRANS_MEDIA_URL': get_static_url(),  # backward compatible
             'request': context['request'],
         })
     return tag_context
