@@ -1,27 +1,43 @@
 import os
 import datetime
+import inlinetrans
 
 from django.conf import settings
+from django.core.management.commands import makemessages
 from django.http import HttpResponseBadRequest, HttpResponse, HttpResponseForbidden
 from django.template import RequestContext
 from django.shortcuts import render_to_response
 from django.utils import simplejson
 from django.utils.encoding import smart_str
 from django.utils.translation import get_language, ugettext as _
-import inlinetrans
 
-from inlinetrans.management.commands.inline_makemessages import make_messages
-from inlinetrans.polib import pofile
+# Copyright (c) 2010-2013 by Yaco Sistemas <ant30tx@gmail.com> or <goinnn@gmail.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this programe.  If not, see <http://www.gnu.org/licenses/>.
+
+from polib import pofile
+
 from inlinetrans.utils import validate_format, find_pos
-from inlinetrans.settings import get_auto_reload_method, get_auto_reload_log, get_auto_reload_time
+from inlinetrans.settings import (get_auto_reload_method, get_auto_reload_log,
+                                  get_auto_reload_time, get_user_can_translate)
 
 
 def set_new_translation(request):
     """
     Post to include a new translation for a msgid
     """
-
-    if not request.user.is_staff:
+    if not get_user_can_translate(request.user):
         return HttpResponseForbidden(_('You have no permission to update translation catalogs'))
     if not request.POST:
         return HttpResponseBadRequest(render_to_response('inlinetrans/response.html',
@@ -30,8 +46,7 @@ def set_new_translation(request):
     else:
         result = {'errors': True,
                   'question': False,
-                  'message': _('Unknow error'),
-                 }
+                  'message': _('Unknow error')}
         selected_pofile = None
         msgid = smart_str(request.POST['msgid'])
         msgstr = smart_str(request.POST['msgstr'])
@@ -42,7 +57,7 @@ def set_new_translation(request):
         if retry != 'false':
             root_path = os.path.dirname(os.path.normpath(os.sys.modules[settings.SETTINGS_MODULE].__file__))
             locale_path = os.path.dirname(os.path.normpath(os.sys.modules[settings.SETTINGS_MODULE].__file__))
-            make_messages(lang, extensions=['.html'], root_path=root_path, locale_path=locale_path)
+            makemessages(lang, extensions=['.html'], root_path=root_path, locale_path=locale_path)
 
         pos = find_pos(lang, include_djangos=True)
         if pos:
@@ -84,14 +99,6 @@ def set_new_translation(request):
     return HttpResponse(simplejson.dumps(result), mimetype='text/plain')
 
 
-def inline_demo(request):
-    """
-    """
-    return render_to_response('inlinetrans/inline_demo.html',
-                              {'INLINETRANS_MEDIA_URL': settings.MEDIA_URL + 'inlinetrans/'},
-                              context_instance=RequestContext(request))
-
-
 def do_restart(request):
     """
     * "test" for a django instance (this do a touch over settings.py for reload)
@@ -100,13 +107,13 @@ def do_restart(request):
     * "wsgi"
     * "restart_script <script_path_name>"
     """
-    if request.user.is_staff:
+    if get_user_can_translate(request.user):
         reload_method = get_auto_reload_method()
         reload_log = get_auto_reload_log()
         reload_time = get_auto_reload_time()
         command = "echo no script"
         if reload_method == 'test':
-            command = 'touch settings.py'
+            command = 'touch %s' % os.path.join(settings.BASEDIR, 'settings.py')
         ## No RedHAT or similars
         elif reload_method == 'apache2':
             command = 'sudo apache2ctl restart'
@@ -119,9 +126,8 @@ def do_restart(request):
         if os.path.exists(os.path.dirname(reload_log)):
             os.system("sleep 2 && %s &> %s & " % (command, reload_log))
         else:
-            print 'The AUTO_RELOAD_LOG directory do not exist'  # Just in case our stdout is logged somewhere
+            print('The AUTO_RELOAD_LOG directory do not exist')  # Just in case our stdout is logged somewhere
             os.system("sleep 2 && %s & " % command)
-
         return render_to_response('inlinetrans/response.html',
                                   {'message': reload_time},
                                   context_instance=RequestContext(request))
